{% load i18n %}
<div id="submit-row page_lock_bar">
    <div id="page_lock_message_display"></div>
    <div id="page_lock_counter_display"></div>
    <div class="g-page-lock__btns">
        <button type="button" id="page_lock_refresh_button">{% trans "REFRESH" %}</button>
        <button type="button" id="page_lock_reload_button">{% trans "RELOAD" %}</button>
    </div>
    <input type="hidden" id="page_lock_template_data" value="{{ page_lock_template_data }}">
    <input type="hidden" id="page_lock_api_interval" value="{{ page_lock_api_interval }}">
</div>
