{% extends 'admin/change_form.html' %}

{% load static %}
{% load page_lock_bar %}

{% block extrahead %}
<script>
    const PAGE_LOCK_URL = {
        'close_page_connection': "{% url 'page_lock_close_page_connection' %}",
        'get_page_connection': "{% url 'page_lock_get_page_connection' %}",
        'open_page_connection': "{% url 'page_lock_open_page_connection' %}"
    }
    window.PAGE_LOCK_URL = PAGE_LOCK_URL
</script>
{{ block.super }}
{% endblock %}


{% block footer %}
    {{ block.super }}
    <div class="g-page-lock">
        {% page_lock_bar_plain %}
    </div>
{% endblock %}
